#!/usr/bin/env node
const execa = require('execa')
const ora = require('ora')
const rm = require('rimraf')
const inquirer = require('inquirer')
const path = require('path')

const downloadTemplate = (templateUrl, clonePath) => {
	return new Promise((resolve, reject) => {
		try {
			execa.sync('git', ['clone', templateUrl, clonePath])
			resolve()
		} catch (error) {
			reject(`下载模板失败：${error.message}`)
		}
	})
}

const questions = [
	{
		type: 'input',
		name: 'projectName',
		message: '输入项目名称',
		validate(val) {
			if (!val) {
				return '请输入项目名称'
			}
			return true
		},
	},
]

inquirer.prompt(questions).then((answers) => {
	const projectName = answers.projectName
	const spinner = ora().start(`下载模板...`)
	downloadTemplate('https://github.com/wjkang/lowcode-mock.git', projectName)
		.then(() => {
			spinner.succeed('下载模板成功')
			rm.sync(path.resolve(process.cwd(), projectName, '.git'))
			spinner.start('初始化项目...')
			try {
				execa.sync(`yarn`, [], {
					cwd: path.resolve(process.cwd(), projectName),
				})
				spinner.succeed('成功！')
			} catch (error) {
				spinner.fail('初始化项目失败，请手动安装依赖')
			}
		})
		.catch((ex) => {
			spinner.fail(ex)
		})
})
